param(
[parameter(Mandatory=$true)]
[ValidatePattern('^[A-Z]:$')] 
$DriveLetter
)

# Check for elevation
If (-NOT ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole(`
    [Security.Principal.WindowsBuiltInRole] "Administrator"))
{
    Write-Warning "Oupps, you need to run this script from an elevated PowerShell prompt!`nPlease start the PowerShell prompt as an Administrator and re-run the script."
	Write-Warning "Aborting script..."
    Break
}

# Check free space on drive - Minimum for the Hydration Kit is 45 GB
$NeededFreeSpace = "48318382080"
$disk = Get-wmiObject Win32_LogicalDisk -computername . | where-object {$_.DeviceID -eq "$($DriveLetter)"} 

[float]$freespace = $disk.FreeSpace;
$freeSpaceGB = [Math]::Round($freespace / 1073741824);

if($disk.FreeSpace -lt $NeededFreeSpace)
{
Write-Warning "Oupps, you need at least 45 GB of free disk space"
Write-Warning "Available free space on $($DriveLetter) is $freeSpaceGB GB"
Write-Warning "Aborting script..."
Break
}

# Validation OK, create Hydration Deployment Share
$MDTServer = (get-wmiobject win32_computersystem).Name

Add-PSSnapIn Microsoft.BDD.PSSnapIn -ErrorAction SilentlyContinue 
New-Item -ItemType Directory $DriveLetter\HydrationCM2012R2\DS
new-PSDrive -Name "DS001" -PSProvider "MDTProvider" -Root "$($DriveLetter)\HydrationCM2012R2\DS" -Description "Hydration CM2012 R2" -NetworkPath "\\$MDTServer\HydrationCM2012R2$" -Verbose | add-MDTPersistentDrive -Verbose

New-Item -ItemType Directory $DriveLetter\HydrationCM2012R2\ISO\Content\Deploy
new-item -path "DS001:\Media" -enable "True" -Name "MEDIA001" -Comments "" -Root "$($DriveLetter)\HydrationCM2012R2\ISO" -SelectionProfile "Everything" -SupportX86 "False" -SupportX64 "True" -GenerateISO "True" -ISOName "HydrationCM2012R2.iso" -Verbose
new-PSDrive -Name "MEDIA001" -PSProvider "MDTProvider" -Root "$($DriveLetter)\HydrationCM2012R2\ISO\Content\Deploy" -Description "Hydration CM2012 R2 Media" -Force -Verbose

# Copy sample files to Hydration Deployment Share
Copy-Item -Path "$($DriveLetter)\HydrationCM2012R2\Source\Hydration\Applications" -Destination "$($DriveLetter)\HydrationCM2012R2\DS" -Recurse -Verbose -Force
Copy-Item -Path "$($DriveLetter)\HydrationCM2012R2\Source\Hydration\Control" -Destination "$($DriveLetter)\HydrationCM2012R2\DS" -Recurse -Verbose -Force
Copy-Item -Path "$($DriveLetter)\HydrationCM2012R2\Source\Hydration\Operating Systems" -Destination "$($DriveLetter)\HydrationCM2012R2\DS" -Recurse -Verbose -Force
Copy-Item -Path "$($DriveLetter)\HydrationCM2012R2\Source\Hydration\Scripts" -Destination "$($DriveLetter)\HydrationCM2012R2\DS" -Recurse -Verbose -Force
Copy-Item -Path "$($DriveLetter)\HydrationCM2012R2\Source\Media\Control" -Destination "$($DriveLetter)\HydrationCM2012R2\ISO\Content\Deploy" -Recurse -Verbose -Force
